// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef QMOBIPOCKET_VERSION_H
#define QMOBIPOCKET_VERSION_H

#define QMOBIPOCKET_VERSION_STRING "2.1.0"
#define QMOBIPOCKET_VERSION_MAJOR 2
#define QMOBIPOCKET_VERSION_MINOR 1
#define QMOBIPOCKET_VERSION_PATCH 0
#define QMOBIPOCKET_VERSION ((2<<16)|(1<<8)|(0))

#endif
